@@ -11,7 +11,7 @@ use URI;
 use String::ShellQuote;
 
 my $app = 'eg/dot-psgi/Hello.psgi';
-my $ab  = 'ab -t 1 -c 10 -k';
+my $ab  = 'ab -t 1 -c 10 -k -q';
 my $url = 'http://127.0.0.1/';
 
 my @try = (
@@ -24,6 +24,7 @@ my @try = (
     [ '+POE::Component::Server::PSGI' ],
     [ 'Starlet', ' (workers=10)', max_workers => 10 ],
     [ 'Starman', ' (workers=10)', workers => 10 ],
+    [ 'Feersum' ],
 );
 
 my @backends;
