@@ -27,7 +27,10 @@ sub load_class {
 sub is_real_fh ($) {
     my $fh = shift;
 
-    return FALSE if -p $fh or -c _ or -b _;
+    {
+        no warnings 'uninitialized';
+        return FALSE if -p $fh or -c _ or -b _;
+    }
 
     my $reftype = Scalar::Util::reftype($fh) or return;
     if (   $reftype eq 'IO'
@@ -73,8 +76,6 @@ sub content_length {
         }
         return $cl;
     } elsif ( is_real_fh($body) ) {
-        warn is_real_fh($body);
-        warn -s $body;
         return (-s $body) - tell($body);
     }
 
